@@ -2,12 +2,12 @@ package proxy
 
 import (
 	"errors"
-	"github.com/e14914c0-6759-480d-be89-66b7b7676451/BitterJohn/pool"
 	"github.com/mzz2017/gg/infra/ip_mtu_trie"
+	"github.com/mzz2017/softwind/pool"
 	"github.com/sirupsen/logrus"
 	"golang.org/x/net/proxy"
-	"inet.af/netaddr"
 	"net"
+	"net/netip"
 	"strconv"
 	"strings"
 	"sync"
@@ -42,7 +42,7 @@ func New(logger *logrus.Logger, dialer proxy.Dialer) *Proxy {
 	}
 }
 
-func (p *Proxy) AllocProjection(target string) (loopback netaddr.IP) {
+func (p *Proxy) AllocProjection(target string) (loopback netip.Addr) {
 	p.mutex.Lock()
 	defer p.mutex.Unlock()
 	if strings.Contains(target, ":") {
@@ -54,9 +54,12 @@ func (p *Proxy) AllocProjection(target string) (loopback netaddr.IP) {
 	}
 }
 
-func (p *Proxy) GetProjection(ip netaddr.IP) (target string) {
+func (p *Proxy) GetProjection(ip netip.Addr) (target string) {
 	p.mutex.Lock()
 	defer p.mutex.Unlock()
+	if ip.Is4In6() {
+		ip = netip.AddrFrom4(ip.As4())
+	}
 	if ip.IsLoopback() {
 		// loopback IP -> target address
 		return p.addrMapper.Get(ip)
@@ -66,7 +69,7 @@ func (p *Proxy) GetProjection(ip netaddr.IP) (target string) {
 	}
 }
 
-func (p *Proxy) GetRealIP(fakeIP netaddr.IP) (realIP netaddr.IP, ok bool) {
+func (p *Proxy) GetRealIP(fakeIP netip.Addr) (realIP netip.Addr, ok bool) {
 	return p.realIPMapper.Get(fakeIP)
 }
 
